==> electron-to-chromium-1.3.36.jar: META-INF/resources/webjars/electron-to-chromium/1.3.36/full-versions.js <==
module.exports = {
	"2.0.0-beta.2": "61.0.3163.100",
	"2.0.0-beta.1": "61.0.3163.100",
	"1.8.3": "59.0.3071.115",
	"1.8.2": "59.0.3071.115",
	"1.8.2-beta.5": "59.0.3071.115",
	"1.8.2-beta.4": "59.0.3071.115",
	"1.8.2-beta.3": "59.0.3071.115",
	"1.8.2-beta.2": "59.0.3071.115",
	"1.8.2-beta.1": "59.0.3071.115",
	"1.8.1": "59.0.3071.115",
	"1.8.0": "59.0.3071.115",
	"1.7.12": "58.0.3029.110",
	"1.7.11": "58.0.3029.110",
	"1.7.10": "58.0.3029.110",
	"1.7.9": "58.0.3029.110",
	"1.7.8": "58.0.3029.110",
	"1.7.7": "58.0.3029.110",
	"1.7.6": "58.0.3029.110",
	"1.7.5": "58.0.3029.110",
	"1.7.4": "58.0.3029.110",
	"1.7.3": "58.0.3029.110",
	"1.7.2": "58.0.3029.110",
	"1.7.1": "58.0.3029.110",
	"1.7.0": "58.0.3029.110",
	"1.6.17": "56.0.2924.87",
	"1.6.16": "56.0.2924.87",
	"1.6.15": "56.0.2924.87",
	"1.6.14": "56.0.2924.87",
	"1.6.13": "56.0.2924.87",
	"1.6.12": "56.0.2924.87",
	"1.6.11": "56.0.2924.87",
	"1.6.10": "56.0.2924.87",
	"1.6.9": "56.0.2924.87",
	"1.6.8": "56.0.2924.87",
	"1.6.7": "56.0.2924.87",
	"1.6.6": "56.0.2924.87",
	"1.6.5": "56.0.2924.87",
	"1.6.4": "56.0.2924.87",
	"1.6.3": "56.0.2924.87",
	"1.6.2": "56.0.2924.87",
	"1.6.1": "56.0.2924.87",
	"1.6.0": "56.0.2924.87",
	"1.5.1": "54.0.2840.101",
	"1.5.0": "54.0.2840.101",
	"1.4.16": "53.0.2785.143",
	"1.4.15": "53.0.2785.143",
	"1.4.14": "53.0.2785.143",
	"1.4.13": "53.0.2785.143",
	"1.4.12": "54.0.2840.51",
	"1.4.11": "53.0.2785.143",
	"1.4.10": "53.0.2785.143",
	"1.4.8": "53.0.2785.143",
	"1.4.7": "53.0.2785.143",
	"1.4.6": "53.0.2785.143",
	"1.4.5": "53.0.2785.113",
	"1.4.4": "53.0.2785.113",
	"1.4.3": "53.0.2785.113",
	"1.4.2": "53.0.2785.113",
	"1.4.1": "53.0.2785.113",
	"1.4.0": "53.0.2785.113",
	"1.3.15": "52.0.2743.82",
	"1.3.14": "52.0.2743.82",
	"1.3.13": "52.0.2743.82",
	"1.3.10": "52.0.2743.82",
	"1.3.9": "52.0.2743.82",
	"1.3.7": "52.0.2743.82",
	"1.3.6": "52.0.2743.82",
	"1.3.5": "52.0.2743.82",
	"1.3.4": "52.0.2743.82",
	"1.3.3": "52.0.2743.82",
	"1.3.2": "52.0.2743.82",
	"1.3.1": "52.0.2743.82",
	"1.3.0": "52.0.2743.82",
	"1.2.8": "51.0.2704.106",
	"1.2.7": "51.0.2704.106",
	"1.2.6": "51.0.2704.106",
	"1.2.5": "51.0.2704.103",
	"1.2.4": "51.0.2704.103",
	"1.2.3": "51.0.2704.84",
	"1.2.2": "51.0.2704.84",
	"1.2.1": "51.0.2704.63",
	"1.2.0": "51.0.2704.63",
	"1.1.3": "50.0.2661.102",
	"1.1.2": "50.0.2661.102",
	"1.1.1": "50.0.2661.102",
	"1.1.0": "50.0.2661.102",
	"1.0.2": "49.0.2623.75",
	"1.0.1": "49.0.2623.75",
	"1.0.0": "49.0.2623.75",
	"0.37.8": "49.0.2623.75",
	"0.37.7": "49.0.2623.75",
	"0.37.6": "49.0.2623.75",
	"0.37.5": "49.0.2623.75",
	"0.37.4": "49.0.2623.75",
	"0.37.3": "49.0.2623.75",
	"0.37.1": "49.0.2623.75",
	"0.37.0": "49.0.2623.75",
	"0.36.12": "47.0.2526.110",
	"0.36.11": "47.0.2526.110",
	"0.36.10": "47.0.2526.110",
	"0.36.9": "47.0.2526.110",
	"0.36.8": "47.0.2526.110",
	"0.36.7": "47.0.2526.110",
	"0.36.6": "47.0.2526.110",
	"0.36.5": "47.0.2526.110",
	"0.36.4": "47.0.2526.73",
	"0.36.3": "47.0.2526.73",
	"0.36.2": "47.0.2526.73",
	"0.36.0": "47.0.2526.73",
	"0.35.5": "45.0.2454.85",
	"0.35.4": "45.0.2454.85",
	"0.35.3": "45.0.2454.85",
	"0.35.2": "45.0.2454.85",
	"0.35.1": "45.0.2454.85",
	"0.34.4": "45.0.2454.85",
	"0.34.3": "45.0.2454.85",
	"0.34.2": "45.0.2454.85",
	"0.34.1": "45.0.2454.85",
	"0.34.0": "45.0.2454.85",
	"0.33.9": "45.0.2454.85",
	"0.33.8": "45.0.2454.85",
	"0.33.7": "45.0.2454.85",
	"0.33.6": "45.0.2454.85",
	"0.33.4": "45.0.2454.85",
	"0.33.3": "45.0.2454.85",
	"0.33.2": "45.0.2454.85",
	"0.33.1": "45.0.2454.85",
	"0.33.0": "45.0.2454.85",
	"0.32.3": "45.0.2454.85",
	"0.32.2": "45.0.2454.85",
	"0.31.2": "45.0.2454.85",
	"0.31.0": "44.0.2403.125",
	"0.30.4": "44.0.2403.125",
	"0.29.2": "43.0.2357.65",
	"0.29.1": "43.0.2357.65",
	"0.28.3": "43.0.2357.65",
	"0.28.2": "43.0.2357.65",
	"0.28.1": "43.0.2357.65",
	"0.28.0": "43.0.2357.65",
	"0.27.3": "43.0.2357.65",
	"0.27.2": "43.0.2357.65",
	"0.27.1": "42.0.2311.107",
	"0.27.0": "42.0.2311.107",
	"0.26.1": "42.0.2311.107",
	"0.26.0": "42.0.2311.107",
	"0.25.3": "42.0.2311.107",
	"0.25.2": "42.0.2311.107",
	"0.25.1": "42.0.2311.107",
	"0.25.0": "42.0.2311.107",
	"0.24.0": "41.0.2272.76",
	"0.23.0": "41.0.2272.76",
	"0.22.3": "41.0.2272.76",
	"0.22.2": "41.0.2272.76",
	"0.22.1": "41.0.2272.76",
	"0.21.3": "41.0.2272.76",
	"0.21.2": "40.0.2214.91",
	"0.21.1": "40.0.2214.91",
	"0.21.0": "40.0.2214.91",
	"0.20.8": "39.0.2171.65",
	"0.20.7": "39.0.2171.65",
	"0.20.6": "39.0.2171.65",
	"0.20.5": "39.0.2171.65",
	"0.20.4": "39.0.2171.65",
	"0.20.3": "39.0.2171.65",
	"0.20.2": "39.0.2171.65",
	"0.20.1": "39.0.2171.65",
	"0.20.0": "39.0.2171.65"
};

==> electron-to-chromium-1.3.45.jar: META-INF/resources/webjars/electron-to-chromium/1.3.45/full-versions.js <==
module.exports = {
	"2.0.0": "61.0.3163.100",
	"2.0.0-beta.8": "61.0.3163.100",
	"2.0.0-beta.7": "61.0.3163.100",
	"2.0.0-beta.6": "61.0.3163.100",
	"2.0.0-beta.5": "61.0.3163.100",
	"2.0.0-beta.4": "61.0.3163.100",
	"2.0.0-beta.3": "61.0.3163.100",
	"2.0.0-beta.2": "61.0.3163.100",
	"2.0.0-beta.1": "61.0.3163.100",
	"1.8.6": "59.0.3071.115",
	"1.8.5": "59.0.3071.115",
	"1.8.4": "59.0.3071.115",
	"1.8.3": "59.0.3071.115",
	"1.8.2": "59.0.3071.115",
	"1.8.2-beta.5": "59.0.3071.115",
	"1.8.2-beta.4": "59.0.3071.115",
	"1.8.2-beta.3": "59.0.3071.115",
	"1.8.2-beta.2": "59.0.3071.115",
	"1.8.2-beta.1": "59.0.3071.115",
	"1.8.1": "59.0.3071.115",
	"1.8.0": "59.0.3071.115",
	"1.7.14": "58.0.3029.110",
	"1.7.13": "58.0.3029.110",
	"1.7.12": "58.0.3029.110",
	"1.7.11": "58.0.3029.110",
	"1.7.10": "58.0.3029.110",
	"1.7.9": "58.0.3029.110",
	"1.7.8": "58.0.3029.110",
	"1.7.7": "58.0.3029.110",
	"1.7.6": "58.0.3029.110",
	"1.7.5": "58.0.3029.110",
	"1.7.4": "58.0.3029.110",
	"1.7.3": "58.0.3029.110",
	"1.7.2": "58.0.3029.110",
	"1.7.1": "58.0.3029.110",
	"1.7.0": "58.0.3029.110",
	"1.6.17": "56.0.2924.87",
	"1.6.16": "56.0.2924.87",
	"1.6.15": "56.0.2924.87",
	"1.6.14": "56.0.2924.87",
	"1.6.13": "56.0.2924.87",
	"1.6.12": "56.0.2924.87",
	"1.6.11": "56.0.2924.87",
	"1.6.10": "56.0.2924.87",
	"1.6.9": "56.0.2924.87",
	"1.6.8": "56.0.2924.87",
	"1.6.7": "56.0.2924.87",
	"1.6.6": "56.0.2924.87",
	"1.6.5": "56.0.2924.87",
	"1.6.4": "56.0.2924.87",
	"1.6.3": "56.0.2924.87",
	"1.6.2": "56.0.2924.87",
	"1.6.1": "56.0.2924.87",
	"1.6.0": "56.0.2924.87",
	"1.5.1": "54.0.2840.101",
	"1.5.0": "54.0.2840.101",
	"1.4.16": "53.0.2785.143",
	"1.4.15": "53.0.2785.143",
	"1.4.14": "53.0.2785.143",
	"1.4.13": "53.0.2785.143",
	"1.4.12": "54.0.2840.51",
	"1.4.11": "53.0.2785.143",
	"1.4.10": "53.0.2785.143",
	"1.4.8": "53.0.2785.143",
	"1.4.7": "53.0.2785.143",
	"1.4.6": "53.0.2785.143",
	"1.4.5": "53.0.2785.113",
	"1.4.4": "53.0.2785.113",
	"1.4.3": "53.0.2785.113",
	"1.4.2": "53.0.2785.113",
	"1.4.1": "53.0.2785.113",
	"1.4.0": "53.0.2785.113",
	"1.3.15": "52.0.2743.82",
	"1.3.14": "52.0.2743.82",
	"1.3.13": "52.0.2743.82",
	"1.3.10": "52.0.2743.82",
	"1.3.9": "52.0.2743.82",
	"1.3.7": "52.0.2743.82",
	"1.3.6": "52.0.2743.82",
	"1.3.5": "52.0.2743.82",
	"1.3.4": "52.0.2743.82",
	"1.3.3": "52.0.2743.82",
	"1.3.2": "52.0.2743.82",
	"1.3.1": "52.0.2743.82",
	"1.3.0": "52.0.2743.82",
	"1.2.8": "51.0.2704.106",
	"1.2.7": "51.0.2704.106",
	"1.2.6": "51.0.2704.106",
	"1.2.5": "51.0.2704.103",
	"1.2.4": "51.0.2704.103",
	"1.2.3": "51.0.2704.84",
	"1.2.2": "51.0.2704.84",
	"1.2.1": "51.0.2704.63",
	"1.2.0": "51.0.2704.63",
	"1.1.3": "50.0.2661.102",
	"1.1.2": "50.0.2661.102",
	"1.1.1": "50.0.2661.102",
	"1.1.0": "50.0.2661.102",
	"1.0.2": "49.0.2623.75",
	"1.0.1": "49.0.2623.75",
	"1.0.0": "49.0.2623.75",
	"0.37.8": "49.0.2623.75",
	"0.37.7": "49.0.2623.75",
	"0.37.6": "49.0.2623.75",
	"0.37.5": "49.0.2623.75",
	"0.37.4": "49.0.2623.75",
	"0.37.3": "49.0.2623.75",
	"0.37.1": "49.0.2623.75",
	"0.37.0": "49.0.2623.75",
	"0.36.12": "47.0.2526.110",
	"0.36.11": "47.0.2526.110",
	"0.36.10": "47.0.2526.110",
	"0.36.9": "47.0.2526.110",
	"0.36.8": "47.0.2526.110",
	"0.36.7": "47.0.2526.110",
	"0.36.6": "47.0.2526.110",
	"0.36.5": "47.0.2526.110",
	"0.36.4": "47.0.2526.73",
	"0.36.3": "47.0.2526.73",
	"0.36.2": "47.0.2526.73",
	"0.36.0": "47.0.2526.73",
	"0.35.5": "45.0.2454.85",
	"0.35.4": "45.0.2454.85",
	"0.35.3": "45.0.2454.85",
	"0.35.2": "45.0.2454.85",
	"0.35.1": "45.0.2454.85",
	"0.34.4": "45.0.2454.85",
	"0.34.3": "45.0.2454.85",
	"0.34.2": "45.0.2454.85",
	"0.34.1": "45.0.2454.85",
	"0.34.0": "45.0.2454.85",
	"0.33.9": "45.0.2454.85",
	"0.33.8": "45.0.2454.85",
	"0.33.7": "45.0.2454.85",
	"0.33.6": "45.0.2454.85",
	"0.33.4": "45.0.2454.85",
	"0.33.3": "45.0.2454.85",
	"0.33.2": "45.0.2454.85",
	"0.33.1": "45.0.2454.85",
	"0.33.0": "45.0.2454.85",
	"0.32.3": "45.0.2454.85",
	"0.32.2": "45.0.2454.85",
	"0.31.2": "45.0.2454.85",
	"0.31.0": "44.0.2403.125",
	"0.30.4": "44.0.2403.125",
	"0.29.2": "43.0.2357.65",
	"0.29.1": "43.0.2357.65",
	"0.28.3": "43.0.2357.65",
	"0.28.2": "43.0.2357.65",
	"0.28.1": "43.0.2357.65",
	"0.28.0": "43.0.2357.65",
	"0.27.3": "43.0.2357.65",
	"0.27.2": "43.0.2357.65",
	"0.27.1": "42.0.2311.107",
	"0.27.0": "42.0.2311.107",
	"0.26.1": "42.0.2311.107",
	"0.26.0": "42.0.2311.107",
	"0.25.3": "42.0.2311.107",
	"0.25.2": "42.0.2311.107",
	"0.25.1": "42.0.2311.107",
	"0.25.0": "42.0.2311.107",
	"0.24.0": "41.0.2272.76",
	"0.23.0": "41.0.2272.76",
	"0.22.3": "41.0.2272.76",
	"0.22.2": "41.0.2272.76",
	"0.22.1": "41.0.2272.76",
	"0.21.3": "41.0.2272.76",
	"0.21.2": "40.0.2214.91",
	"0.21.1": "40.0.2214.91",
	"0.21.0": "40.0.2214.91",
	"0.20.8": "39.0.2171.65",
	"0.20.7": "39.0.2171.65",
	"0.20.6": "39.0.2171.65",
	"0.20.5": "39.0.2171.65",
	"0.20.4": "39.0.2171.65",
	"0.20.3": "39.0.2171.65",
	"0.20.2": "39.0.2171.65",
	"0.20.1": "39.0.2171.65",
	"0.20.0": "39.0.2171.65"
};
